/* 
* -cr_beg-
* ********************************************************************
* IBM Confidential
* OCO Source Materials
* 5724-U38, 5724-U39, 5724-U48, 5655-V17, 5655-V19, 5655-V35, 5655-V37
* Copyright IBM Corp. 2013
* The source code for this program is not published or otherwise
* divested of its trade secrets, irrespective of what has
* been deposited with the U.S. Copyright Office.
* ********************************************************************
* -cr_end-
*/ 
//#pragma once
#include <sqludf.h>
#include <stdio.h>
extern "C"
{
#include "ODPPCmnAPI.h"
#include "ODPPCmnErrCodes.h"
#include "ODPPCommonH.h"
}

#ifndef __DB2DATA__
#define __DB2DATA__

//code page 1200 of DB2 database means UTF16
#define DB2_UTF16_CP                   1200
//code page 1208 of DB2 database means UTF8
#define DB2_UTF8_CP                    1208


typedef enum DATETIME_TYPE
{
    UDF_NONE = 0,
    UDF_DATE,
    UDF_TIME,
    UDF_TIMESTAMP
}DATETIME_TYPE;

class CDB2Data
{
protected:
   short                msDataType;
   short                msNullInd;
   int                  miLength;
   int                  miCodePage;
   
public:
   
   CDB2Data(void);
   short                GetDataType(void);
   short                GetNullInd(void);
   int                  GetLength(void);
   int                  GetCodePage(void);

   RETVAL   SetDataType(short sDataType);
   RETVAL   SetNullInd(short sNullInd);
   RETVAL   SetLength(int iLength);
   RETVAL   SetCodePage(int iCodePage);

   //VIRTUAL SET FUNCTIONS
   virtual RETVAL SetString( 
               SQLUDF_CHAR *pStr,
               short sNullInd,
               int iLen,
               SQLUDF_DBINFO *pDbInfo);

   virtual RETVAL SetString( 
               SQLUDF_GRAPH *pStr,
               short sNullInd,
               int iLen,
               SQLUDF_DBINFO *pDbInfo);

   virtual RETVAL SetShort(  
                  SQLUDF_SMALLINT *pShort, 
                  short sNullInd);
   
   virtual RETVAL SetInt( SQLUDF_INTEGER *pInt, 
                  short sNullInd);
   

   virtual RETVAL SetInt64(  
                  SQLUDF_BIGINT *pLong, 
                  short sNullInd);
   
   virtual RETVAL SetFloat(  
                  SQLUDF_REAL *pFloat, 
                  short sNullInd);

   virtual RETVAL SetDouble(  
                  SQLUDF_DOUBLE *pDbl, 
                  short sNullInd);

   virtual RETVAL SetDateTime( 
                  char *pDateTime, 
                  short sNullInd,
                  int iLen,
		            DATETIME_TYPE type,
                  SQLUDF_DBINFO *pDbInfo);

   virtual RETVAL SetDate( 
                  ODPP_ODBC_DATE *pDate);

   virtual RETVAL SetTime( 
                  ODPP_ODBC_TIME *pTime);

   virtual RETVAL SetTimeStamp( 
                  ODPP_ODBC_TIMESTAMP *pTimeStamp);

   //VIRTUAL GET FUNCTIONS
   virtual RETVAL GetShort( 
                  SQLUDF_SMALLINT **pShort,
                  short *pNullInd);

   virtual RETVAL GetInteger( 
                  SQLUDF_INTEGER **pInt,
                  short *pNullInd);

   virtual RETVAL GetInt64( 
                  SQLUDF_BIGINT **pInt64,
                  short *pNullInd);

   virtual RETVAL GetFloat( 
                  SQLUDF_REAL **pFloat,
                  short *pNullInd);

   virtual RETVAL GetDouble( 
                  SQLUDF_DOUBLE **pDbl,
                  short *pNullInd);

   virtual RETVAL GetString( 
               SQLUDF_CHAR **pStr,
               short *pNullInd,
               int *pLen,
               int *pCodePage);

   virtual RETVAL GetString( 
               SQLUDF_GRAPH **pgStr,
               short *pNullInd,
               int *pLen,
               int *pCodePage);

   virtual RETVAL GetDateTime( 
                  char **pDateTime,
                  short *pNullInd,
                  int *pLen);

   virtual ~CDB2Data(void);
};

class CDB2Number : public CDB2Data
{
private:
   
   typedef union DB2NUMDATA
   {
      SQLUDF_SMALLINT   *mpsData;
      SQLUDF_INTEGER    *mpiData;
      SQLUDF_BIGINT     *mpi64Data;
      SQLUDF_REAL       *mpFloat;
      SQLUDF_DOUBLE     *mpDbl;
   }DB2NUMDATA;

   DB2NUMDATA m_db2Data;
public:
   CDB2Number(void);

   //Various constructors for different data types
   CDB2Number( SQLUDF_SMALLINT *pShort, 
               short sNullInd);
      
   CDB2Number( SQLUDF_INTEGER *pInt, 
               short sNullInd);
   
   CDB2Number( SQLUDF_BIGINT *pInt64, 
               short sNullInd);
   
   CDB2Number( SQLUDF_REAL *pFloat, 
               short sNullInd);

   CDB2Number( SQLUDF_DOUBLE *pDbl, 
               short sNullInd);


   RETVAL SetShort(  
                  SQLUDF_SMALLINT *pShort, 
                  short sNullInd);
   
   RETVAL SetInt( SQLUDF_INTEGER *pInt, 
                  short sNullInd);
   

   RETVAL SetInt64(  
                  SQLUDF_BIGINT *pInt64, 
                  short sNullInd);
   
   RETVAL SetFloat(  
                  SQLUDF_REAL *pFloat, 
                  short sNullInd);

   RETVAL SetDouble(  
                  SQLUDF_DOUBLE *pDbl, 
                  short sNullInd);

   RETVAL GetShort( 
                  SQLUDF_SMALLINT **pShort,
                  short *pNullInd);

   RETVAL GetInteger( 
                  SQLUDF_INTEGER **pInt,
                  short *pNullInd);

   RETVAL GetInt64( 
                  SQLUDF_BIGINT **pInt64,
                  short *pNullInd);

   RETVAL GetFloat( 
                  SQLUDF_REAL **pFloat,
                  short *pNullInd);

   RETVAL GetDouble( 
                  SQLUDF_DOUBLE **pDbl,
                  short *pNullInd);

   virtual ~CDB2Number(void);
};

class CDB2String : public CDB2Data
{
private:
   SQLUDF_CHAR 	*mpCharStr;
   SQLUDF_GRAPH  	*mpGraphicStr;
   ODPP_STR_TYPE  mStrType;
   int            miBytes;

public:
   CDB2String( void);

   //Creates a DB2String instance with supplie data
   CDB2String( SQLUDF_CHAR *pStr,
               short sNullInd,
               int iLen,
               SQLUDF_DBINFO *pDbInfo);

   CDB2String( SQLUDF_GRAPH *pgStr,
               short sNullInd,
               int iLen,
               SQLUDF_DBINFO *pDbInfo);
	
   RETVAL SetString( 
               SQLUDF_CHAR *pStr,
               short sNullInd,
               int iLen,
               SQLUDF_DBINFO *pDbInfo);

   RETVAL SetString( 
               SQLUDF_GRAPH *pgStr,
               short sNullInd,
               int iLen,
               SQLUDF_DBINFO *pDbInfo);

   RETVAL GetString( 
               SQLUDF_CHAR **pStr,
               short *pNullInd,
               int *pLen,
               int *pCodePage);

   RETVAL GetString( 
               SQLUDF_GRAPH **pgStr,
               short *pNullInd,
               int *pLen,
               int *pCodePage);

   int GetBytes(void){ return miBytes; }

   ODPP_STR_TYPE GetStrType(void){ return mStrType; }

   virtual ~CDB2String(void);
};

class CDB2DateTime : public CDB2Data
{
public:

   CDB2DateTime(  void);
   CDB2DateTime(  char *pDateTime, 
                  short sNullInd,
                  int iLen,
		            DATETIME_TYPE type,
                  SQLUDF_DBINFO *pDbInfo);

   RETVAL GetDateTime( 
                  char **pDateTime,
                  short *pNullInd,
                  int *pLen);

   RETVAL SetDateTime( 
                  char *pDateTime, 
                  short sNullInd,
                  int iLen,
		            DATETIME_TYPE type,
                  SQLUDF_DBINFO *pDbInfo);

   RETVAL SetDate( 
                  ODPP_ODBC_DATE *pDate);

   RETVAL SetTime( 
                  ODPP_ODBC_TIME *pTime);

   RETVAL SetTimeStamp( 
                  ODPP_ODBC_TIMESTAMP *pTimeStamp);

   virtual ~CDB2DateTime(void);
private:
   char           *mpDB2DateTime;
   char           mOutDate[32+1];
   DATETIME_TYPE  mDTtype;
   bool           mbReadInternalDate;
};

#endif //__DB2DATA__
