# Command for building ioqdb2udf library on unix platforms 

echo "Build Started"
echo ""
echo "Setting Environment Variables"	
date
echo ""

echo "Enter the platform"
read PLATFORM
if [ "$PLATFORM" == '' ]
then
   echo "No platform specified"
   exit 1 
fi

echo "Enter the path of ODPP bianries"
read SRC
if [ "$SRC" == '' ]
then
   echo "No path specified for ODPP binaries"
   exit 1 
fi

echo "Enter the path of Db2 include"
read DB2_INC
if [ "$DB2_INC" == '' ]
then
   echo "No path specified for DB2 Include"
   exit 1 
fi

echo "Enter compiler path, excluding compiler name"
read CMP_PATH
if [ "$CMP_PATH" == '' ]
then
   echo "No path specified for compiler"
   exit 1 
fi

echo "Source= "$SRC
echo "DB2 Include= "$DB2_INC
echo "Platform= "$PLATFORM
echo "Compiler Path= "$CMP_PATH
echo ""

export COMMON_INC=-D_CPLUSPLUS 
export LIBPATH=.:$SRC:$DB2_INC

if test "$PLATFORM" = "RHEL32"
then
OUTPUT=$SRC/rhel32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for RHEL 32bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m32 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -D_GNU_SOURCE -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o
$CMP_PATH/g++ -m32 -shared -Wl,-soname,libioqdb2udf.so $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -o $OUTPUT/libioqdb2udf.so -L$SRC
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "RHEL64"
then
OUTPUT=$SRC/rhel64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for RHEL 64bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m64 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -D_GNU_SOURCE -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o
$CMP_PATH/g++ -m64 -shared -Wl,-soname,libioqdb2udf.so $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -o $OUTPUT/libioqdb2udf.so -L$SRC
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUSE32"
then
OUTPUT=$SRC/suse32
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for SUSE 32bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m32 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -D_GNU_SOURCE -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o
$CMP_PATH/g++ -m32 -shared -Wl,-soname,libioqdb2udf.so $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -o $OUTPUT/libioqdb2udf.so -L$SRC
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUSE64"
then
OUTPUT=$SRC/suse64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for SUSE 64bit"	
date
echo ""
echo ""
$CMP_PATH/g++ -m64 -Wall -fPIC -c $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -D_GNU_SOURCE -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o
$CMP_PATH/g++ -m64 -shared -Wl,-soname,libioqdb2udf.so $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -o $OUTPUT/libioqdb2udf.so -L$SRC
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "AIX64"
then
OUTPUT=$SRC/aix64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for AIX 64bit"	
date
echo ""
echo ""
$CMP_PATH/xlc++ -c -q64 $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o 
$CMP_PATH/xlc++ -qmkshrobj -q64 $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -o $OUTPUT/libioqdb2udf.so -L$SRC -bnoipath -bE:$SRC/ioqdb2udfunixexp.def
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "HPIA64"
then
OUTPUT=$SRC/hpia64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for HPIA 64bit"	
date
echo ""
echo ""
$CMP_PATH/aCC -c +z -AA +DD64 -mt $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o
$CMP_PATH/aCC -b -Wl,+s,+nodefaultrpath -AA +DD64 -mt -Wl,+h,libioqdb2udf.so $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -L$SRC -lpthread -o $OUTPUT/libioqdb2udf.so
echo ""
echo "Build Completed"	
exit 0
fi

if test "$PLATFORM" = "SUN64"
then
OUTPUT=$SRC/sun64
echo "Deleting Output Files"	
rm -rf $OUTPUT
mkdir $OUTPUT
echo "Building DB2 UDF library for SUN 64bit"	
date
echo ""
echo ""
$CMP_PATH/CC -xarch=generic64 -xcode=pic32 -c $COMMON_INC $SRC/ioqoptimmaskdb2func.cpp -I$SRC -I$DB2_INC -o $OUTPUT/ioqoptimmaskdb2func.o
$CMP_PATH/CC -xarch=generic64 -xcode=pic32 -G -hlibioqdb2udf.so $SRC/odppdb2data.o $OUTPUT/ioqoptimmaskdb2func.o -o $OUTPUT/libioqdb2udf.so -L$SRC -lpthread
echo ""
echo "Build Completed"	
exit 0
fi
